# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.time_stamp import TimeStamp


class UpdateCommentParamsData(UncheckedBaseModel):
    annotation: typing.Optional[str] = pydantic.Field(default=None)
    """
    JSON geometry for on-screen drawings. Allowed for document, image, video, or stream file types. JSON must be stringified.
    """

    completed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Comment completion status
    """

    page: typing.Optional[int] = pydantic.Field(default=None)
    """
    Document page. Only allowed when file type is a pdf document
    """

    text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Comment text
    """

    timestamp: typing.Optional[TimeStamp] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
