# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class FolderMoveParamsData(UncheckedBaseModel):
    parent_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Destination folder ID
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
