# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .field_value_common import FieldValueCommon


class NumberValue(FieldValueCommon):
    value: typing.Optional[float] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
