# This file was auto-generated by Fern from our API Definition.

import typing

FoldersShowRequestInclude = typing.Union[typing.Literal["creator", "project", "project.owner", "metadata"], typing.Any]
