# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .media_link_common import MediaLinkCommon


class OriginalMediaLink(MediaLinkCommon):
    inline_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to view the media file in a web browser in its original resolution and media type.<br>
    HTTP response headers will include Content-Disposition = 'inline;filename=<filename>'.<br>
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
