# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class SelectOption(UncheckedBaseModel):
    display_name: str = pydantic.Field()
    """
    Option display name
    """

    id: str = pydantic.Field()
    """
    Option ID
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
