# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class UpdateToggleDefinitionParamsFieldConfiguration(UncheckedBaseModel):
    color: typing.Optional[str] = pydantic.Field(default=None)
    """
    Color value hex code. ex: #fbd400
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
