# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_events import WebhookEvents


class Webhook(UncheckedBaseModel):
    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Webhook active status
    """

    created_at: dt.datetime
    events: WebhookEvents
    id: str = pydantic.Field()
    """
    Webhook ID
    """

    name: str = pydantic.Field()
    """
    Webhook Name
    """

    updated_at: dt.datetime
    url: str
    workspace_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Workspace ID
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
