# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class VersionStackCreateParamsData(UncheckedBaseModel):
    file_ids: typing.List[str] = pydantic.Field()
    """
    An array of file IDs in the Version Stack.
    <br/>
    The Version Stack will be created by "stacking" the `file_ids` argument in order from left (oldest/bottom version in the stack) to right (newest/top version in the stack).
    <br/>
    Two file IDs are required and up to a maximum of ten. Files must exist in the parent directory identified in the path.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
