# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .user_multi_definition_field_configuration_custom_members_item import (
    UserMultiDefinitionFieldConfigurationCustomMembersItem,
)
from .user_multi_definition_field_configuration_member_options_type import (
    UserMultiDefinitionFieldConfigurationMemberOptionsType,
)


class UserMultiDefinitionFieldConfiguration(UncheckedBaseModel):
    custom_members: typing.List[UserMultiDefinitionFieldConfigurationCustomMembersItem]
    member_options_type: UserMultiDefinitionFieldConfigurationMemberOptionsType
    notify_members: bool = pydantic.Field()
    """
    
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
