# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .links import Links
from .user_role import UserRole


class WorkspaceUserRolesResponse(UncheckedBaseModel):
    """
    Frame.io user role details
    """

    data: typing.List[UserRole] = pydantic.Field()
    """
    User Roles
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
