# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .account_user_role_role import AccountUserRoleRole
from .user import User


class AccountUserRole(UncheckedBaseModel):
    """
    Frame.io Account User Role
    """

    role: typing.Optional[AccountUserRoleRole] = pydantic.Field(default=None)
    """
    Account User Role
    """

    user: User

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
