# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_user_single_definition_params_field_configuration_custom_members_item_type import (
    UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
)


class UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    User Id
    """

    type: UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
