# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .project import Project
from .user import User


class ProjectWithIncludes(Project):
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project Description
    """

    owner: typing.Optional[User] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
