# This file was auto-generated by Fern from our API Definition.

import typing

FiltersEventType = typing.Union[
    typing.Literal[
        "access_request_approved",
        "access_request_denied",
        "access_request_submitted",
        "account_aup_migration_created",
        "account_aup_migration_deleted",
        "account_aup_migration_downgrade_completed",
        "account_aup_migration_downgrade_failed",
        "account_aup_migration_downgrade_requested",
        "account_aup_migration_product_migrated",
        "account_aup_migration_started",
        "account_aup_migration_updated",
        "account_aup_user_migration_completed",
        "account_aup_user_migration_created",
        "account_aup_user_migration_deleted",
        "account_aup_user_migration_failed",
        "account_aup_user_migration_on_hold",
        "account_aup_user_migration_started",
        "account_aup_user_migration_unheld",
        "account_aup_user_migration_updated",
        "account_delinquent",
        "account_field_created",
        "account_field_deleted",
        "account_field_updated",
        "account_fio_version_migrated",
        "account_locked",
        "account_member_created",
        "account_member_deleted",
        "account_member_updated",
        "account_mfa_enforced",
        "account_ownership_transferred",
        "account_permissions_granted_to_user",
        "account_restored",
        "account_updated",
        "account_user_deleted",
        "account_user_group_created",
        "account_user_group_deleted",
        "account_user_group_members_added",
        "account_user_group_members_removed",
        "account_user_group_updated",
        "account_user_updated",
        "action_created",
        "action_deleted",
        "action_updated",
        "admin_update_to_v4",
        "allowed_domain_created",
        "allowed_domain_deleted",
        "anonymous_user_created",
        "asset_assignee_changed",
        "asset_copied",
        "asset_created",
        "asset_deleted",
        "asset_metadata_created",
        "asset_moved",
        "asset_restored",
        "asset_status_changed",
        "asset_updated",
        "asset_versioned",
        "assets_unversioned",
        "bulk_account_deletion_started",
        "bulk_assets_deleted",
        "bulk_assets_restored",
        "bulk_assets_retranscoded",
        "bulk_emails_updated",
        "bulk_projects_activated",
        "bulk_projects_deactivated",
        "bulk_users_removed",
        "collaborator_added",
        "collaborator_deleted",
        "collection_updated",
        "comment_completed",
        "comment_created",
        "comment_deleted",
        "comment_liked",
        "comment_uncompleted",
        "comment_updated",
        "email_address_changed",
        "email_change_confirmation_requested",
        "email_confirmed",
        "file_uploaded",
        "google_auth_disabled",
        "google_auth_enabled",
        "high_risk_sign_up",
        "join_presentation_request_approved",
        "join_project_request_approved",
        "join_request_accepted",
        "join_request_created",
        "join_request_declined",
        "join_request_deleted",
        "join_request_reset",
        "join_review_link_request_approved",
        "join_team_request_approved",
        "label_updated",
        "login_factor_created",
        "login_factor_validated",
        "media_created",
        "media_deleted",
        "metadata_value_updated",
        "new_device_login",
        "new_user_email_confirmation_requested",
        "oauth_app_created",
        "oauth_app_deleted",
        "oauth_app_disabled",
        "oauth_app_enabled",
        "oauth_app_updated",
        "password_changed",
        "password_reset_requested",
        "pending_account_member_created",
        "pending_account_member_deleted",
        "pending_collaborator_created",
        "pending_collaborator_deleted",
        "pending_reviewer_created",
        "pending_reviewer_deleted",
        "pending_team_member_created",
        "pending_team_member_deleted",
        "plan_created",
        "plan_deleted",
        "plan_updated",
        "preference_updated",
        "presentation_created",
        "presentation_deleted",
        "presentation_updated",
        "project_activated",
        "project_archive_completed",
        "project_archived",
        "project_created",
        "project_deactivated",
        "project_deleted",
        "project_field_created",
        "project_field_deleted",
        "project_field_updated",
        "project_invite_link_created",
        "project_invite_link_revoked",
        "project_moved",
        "project_permissions_granted_to_account_user_group",
        "project_permissions_granted_to_user",
        "project_restored",
        "project_unarchive_completed",
        "project_unarchived",
        "project_updated",
        "push_tokens_added",
        "push_tokens_deleted",
        "resource_control_policies_updated",
        "resource_invite_sent",
        "review_link_assets_added",
        "review_link_assets_deleted",
        "review_link_created",
        "review_link_deleted",
        "review_link_emailed",
        "review_link_updated",
        "reviewer_created",
        "reviewer_deleted",
        "role_added",
        "role_removed",
        "sbwm_template_created",
        "sbwm_template_deleted",
        "sbwm_template_updated",
        "session_refreshed",
        "session_revoked",
        "share_activity_tracking_consent_changed",
        "share_branding_preset_updated",
        "share_created",
        "share_deleted",
        "share_invites_sent",
        "share_reviewers_added",
        "share_reviewers_removed",
        "share_updated",
        "share_viewed",
        "subscription_cancelled",
        "subscription_card_updated",
        "subscription_created",
        "subscription_line_item_created",
        "subscription_line_item_deleted",
        "subscription_restored",
        "subscription_updated",
        "team_created",
        "team_creator_updated",
        "team_deleted",
        "team_lifecycle_policy_updated",
        "team_member_created",
        "team_member_deleted",
        "team_member_reset",
        "team_member_updated",
        "team_updated",
        "transcript_completed_self",
        "transcript_diarization_consent_changed",
        "transfer_batch_completed",
        "user_anonymized",
        "user_deactivated",
        "user_login",
        "user_login_attempt",
        "user_logout",
        "user_mfa_enforced",
        "user_reactivated",
        "user_signup",
        "user_token_created",
        "user_token_deleted",
        "user_token_disabled",
        "user_token_enabled",
        "user_token_updated",
        "user_updated",
        "v4_planned_migration_creation_failed",
        "webhook_created",
        "webhook_deleted",
        "webhook_updated",
        "workfront_asset_approval_status_updated",
        "workspace_permissions_granted_to_account_user_group",
        "workspace_permissions_granted_to_user",
    ],
    typing.Any,
]
