# This file was auto-generated by Fern from our API Definition.

import typing

UserSingleDefinitionFieldConfigurationMemberOptionsType = typing.Union[
    typing.Literal["all_project_members", "custom"], typing.Any
]
