# This file was auto-generated by Fern from our API Definition.

import typing

DateDefinitionFieldConfigurationTimeFormat = typing.Union[typing.Literal["twelve_hour", "twenty_four_hour"], typing.Any]
