# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .links import Links
from .workspace_with_includes import WorkspaceWithIncludes


class WorkspacesWithIncludesResponse(UncheckedBaseModel):
    """
    Frame.io workspace details
    """

    data: typing.List[WorkspaceWithIncludes] = pydantic.Field()
    """
    Workspaces
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
