# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_select_multi_definition_params_field_configuration_options_item import (
    UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem,
)


class UpdateSelectMultiDefinitionParamsFieldConfiguration(UncheckedBaseModel):
    enable_add_new: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Allow or disallow adding in new option(s) from the grid/list view
    """

    options: typing.Optional[typing.List[UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem]] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
