# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .toggle_definition_params_field_configuration import ToggleDefinitionParamsFieldConfiguration


class ToggleDefinitionParams(UncheckedBaseModel):
    field_configuration: typing.Optional[ToggleDefinitionParamsFieldConfiguration] = None
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
