# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.webhook_events import WebhookEvents


class WebhookUpdateParamsData(UncheckedBaseModel):
    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Webhook active status
    """

    events: typing.Optional[WebhookEvents] = None
    name: typing.Optional[str] = None
    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL where `event` is sent
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
