# This file was auto-generated by Fern from our API Definition.

import typing

LongTextDefinitionFieldType = typing.Union[
    typing.Literal[
        "text", "long_text", "select", "select_multi", "rating", "number", "toggle", "user_single", "user_multi", "date"
    ],
    typing.Any,
]
