# This file was auto-generated by Fern from our API Definition.

import typing

UpdateRatingDefinitionParamsFieldConfigurationStyle = typing.Union[
    typing.Literal["star", "heart", "thumbs_up"], typing.Any
]
