# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .json_error_response_errors_item_source import JsonErrorResponseErrorsItemSource


class JsonErrorResponseErrorsItem(UncheckedBaseModel):
    detail: str
    source: JsonErrorResponseErrorsItemSource
    title: str

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
