# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class FileCreateRemoteUploadParamsData(UncheckedBaseModel):
    name: str = pydantic.Field()
    """
    File name
    """

    source_url: str = pydantic.Field()
    """
    Source URL - Initiates a remote upload from the provided URL
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
