# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .remove_reviewer_params_data_reviewers import RemoveReviewerParamsDataReviewers


class RemoveReviewerParamsData(UncheckedBaseModel):
    reviewers: RemoveReviewerParamsDataReviewers

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
