# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.asset_share_params_access import AssetShareParamsAccess


class CreateShareParamsData_Asset(UncheckedBaseModel):
    type: typing.Literal["asset"] = "asset"
    access: AssetShareParamsAccess
    asset_ids: typing.Optional[typing.List[str]] = None
    description: typing.Optional[str] = None
    downloading_enabled: typing.Optional[bool] = None
    expiration: typing.Optional[dt.datetime] = None
    name: str
    passphrase: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)


CreateShareParamsData = CreateShareParamsData_Asset
