# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .media_link_common import MediaLinkCommon
from .original_media_link import OriginalMediaLink
from .rendition_media_link import RenditionMediaLink


class MediaLinksCollection(UncheckedBaseModel):
    efficient: typing.Optional[MediaLinkCommon] = None
    high_quality: typing.Optional[MediaLinkCommon] = None
    original: typing.Optional[OriginalMediaLink] = None
    thumbnail: typing.Optional[RenditionMediaLink] = None
    thumbnail_high_quality: typing.Optional[RenditionMediaLink] = None
    video_h_264_180: typing_extensions.Annotated[
        typing.Optional[RenditionMediaLink],
        FieldMetadata(alias="video_h264_180"),
        pydantic.Field(alias="video_h264_180", default=None),
    ]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
