# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class UploadUrl(UncheckedBaseModel):
    size: int = pydantic.Field()
    """
    Upload chunk size
    """

    url: str = pydantic.Field()
    """
    S3 presigned URL. Client should make a PUT request to this URL that includes the "x-amz-acl: private" header along with the file or file chunk data.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
