# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .too_many_requests_errors_item_source import TooManyRequestsErrorsItemSource


class TooManyRequestsErrorsItem(UncheckedBaseModel):
    detail: str
    source: typing.Optional[TooManyRequestsErrorsItemSource] = None
    title: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
