# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .share import Share


class AddAssetResponseData(Share):
    asset_added: str = pydantic.Field()
    """
    ID for asset added
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
