# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class BulkUpdateMetadataParamsDataValuesItem(UncheckedBaseModel):
    field_definition_id: str
    value: typing.Any

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
