# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .audit_logwith_includes import AuditLogwithIncludes
from .links import Links


class AuditLogsWithIncludesResponse(UncheckedBaseModel):
    """
    Frame.io Audit log events
    """

    data: typing.List[AuditLogwithIncludes] = pydantic.Field()
    """
    Audit logs
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
