# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class MediaLinkCommon(UncheckedBaseModel):
    download_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to download the media file.<br>
    HTTP response headers will include Content-Disposition = 'attachment;filename=<filename>'.<br>
    Watermarks may be applied for transcode links as per Account settings and User permissions.<br>
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
