# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .workspace import Workspace


class WorkspaceResponse(UncheckedBaseModel):
    """
    Frame.io workspace details
    """

    data: Workspace

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
