# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_create_response_data import WebhookCreateResponseData


class WebhookCreateResponse(UncheckedBaseModel):
    """
    Returns a single webhook with secret.
    """

    data: WebhookCreateResponseData

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
