# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .number_definition_field_configuration_number_format import NumberDefinitionFieldConfigurationNumberFormat


class NumberDefinitionFieldConfiguration(UncheckedBaseModel):
    number_format: typing.Optional[NumberDefinitionFieldConfigurationNumberFormat] = pydantic.Field(default=None)
    """
    Number format
    """

    scale: int = pydantic.Field()
    """
    Number scale. Indicates the number of decimal places of precision for the number value
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
