# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .rating_definition_field_configuration_style import RatingDefinitionFieldConfigurationStyle


class RatingDefinitionFieldConfiguration(UncheckedBaseModel):
    color: typing.Optional[str] = pydantic.Field(default=None)
    """
    Color value hex code for the `style` icon symbols. ex: #fbd400
    """

    max_value: int
    style: typing.Optional[RatingDefinitionFieldConfigurationStyle] = pydantic.Field(default=None)
    """
    Field type
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
