# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.email import Email
from ...types.uuid_ import Uuid


class AddReviewersToShareParamsDataReviewers(UncheckedBaseModel):
    adobe_user_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Adobe User IDs
    """

    emails: typing.Optional[typing.List[Email]] = pydantic.Field(default=None)
    """
    Email Addresses
    """

    user_ids: typing.Optional[typing.List[Uuid]] = pydantic.Field(default=None)
    """
    User IDs
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
