# This file was auto-generated by Fern from our API Definition.

import typing

NumberDefinitionFieldConfigurationNumberFormat = typing.Union[
    typing.Literal["bitrate", "bits", "duration", "framerate", "frequency", "storage", "timecode"], typing.Any
]
