# This file was auto-generated by Fern from our API Definition.

import typing

UpdateDateDefinitionParamsFieldConfigurationDisplayFormat = typing.Union[
    typing.Literal["local", "friendly", "usa", "euro", "iso"], typing.Any
]
