# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class Workspace(UncheckedBaseModel):
    """
    Frame.io workspace
    """

    account_id: str = pydantic.Field()
    """
    Account ID
    """

    created_at: dt.datetime = pydantic.Field()
    """
    Created Timestamp
    """

    id: str = pydantic.Field()
    """
    Workspace ID
    """

    name: str = pydantic.Field()
    """
    Workspace Name
    """

    updated_at: dt.datetime = pydantic.Field()
    """
    Updated Timestamp
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
