# This file was auto-generated by Fern from our API Definition.

import typing

FileWithMediaLinksInclude = typing.Union[
    typing.Literal[
        "media_links",
        "media_links.original",
        "media_links.thumbnail",
        "media_links.thumbnail_high_quality",
        "media_links.video_h264_180",
        "media_links.high_quality",
        "media_links.efficient",
        "creator",
        "project",
        "project.owner",
        "metadata",
    ],
    typing.Any,
]
