# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .user import User
from .user_multi_definition import UserMultiDefinition


class UserMultiDefinitionWithIncludes(UserMultiDefinition):
    creator: typing.Optional[User] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
