# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class Links(UncheckedBaseModel):
    """
    Links to paginated data
    """

    next: typing.Optional[str] = pydantic.Field(default=None)
    """
    "Link to next page of data.
    <br/>
    This link is the request path with the addition of the `after` query parameter to fetch the next page of results.
    Optional query parameters `page_size` and `include_total_count` are supported when paginating data."
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
