# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class AddAssetParamsData(UncheckedBaseModel):
    asset_id: str = pydantic.Field()
    """
    ID for asset to be added
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
