# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .user_value_type import UserValueType


class UserValue(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    User Id or Account User Group Id
    """

    type: UserValueType

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
