# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .comment import Comment
from .user import User


class CommentWithIncludes(Comment):
    owner: typing.Optional[User] = None
    replies: typing.Optional[typing.List[Comment]] = pydantic.Field(default=None)
    """
    Replies
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
