# This file was auto-generated by Fern from our API Definition.

import typing

UserRoleRole = typing.Union[
    typing.Literal["full_access", "editor", "edit_only", "commenter", "viewer", "admin", "owner"], typing.Any
]
