# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_with_includes import WebhookWithIncludes


class WebhookWithIncludesResponse(UncheckedBaseModel):
    data: WebhookWithIncludes

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
