# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .asset_common_with_includes import AssetCommonWithIncludes
from .file_with_includes_status import FileWithIncludesStatus
from .media_links_collection import MediaLinksCollection


class FileWithIncludes(AssetCommonWithIncludes):
    file_size: int = pydantic.Field()
    """
    File size in bytes
    """

    media_links: typing.Optional[MediaLinksCollection] = None
    media_type: str = pydantic.Field()
    """
    File media type
    """

    status: FileWithIncludesStatus

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
