# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class FileUploadStatus(UncheckedBaseModel):
    filetype: str = pydantic.Field()
    """
    File type
    """

    id: str = pydantic.Field()
    """
    File ID
    """

    upload_complete: bool = pydantic.Field()
    """
    Indicates if upload is complete
    """

    upload_completed_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Timestamp when the asset was successfully uploaded
    """

    upload_failed: bool = pydantic.Field()
    """
    Indicates if upload failed
    """

    uploaded_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Timestamp when the operation started
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
