# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class User(UncheckedBaseModel):
    """
    User details
    """

    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    User active status
    """

    adobe_user_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Adobe user ID
    """

    avatar_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    User avatar image url
    """

    email: str = pydantic.Field()
    """
    User email
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    User ID - can be null for invited users with no frame account
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    User name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
