# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .date_definition_field_configuration_display_format import DateDefinitionFieldConfigurationDisplayFormat
from .date_definition_field_configuration_time_format import DateDefinitionFieldConfigurationTimeFormat


class DateDefinitionFieldConfiguration(UncheckedBaseModel):
    display_format: DateDefinitionFieldConfigurationDisplayFormat
    display_timezone: typing.Optional[bool] = None
    include_time: typing.Optional[bool] = pydantic.Field(default=None)
    """
    
    """

    time_format: typing.Optional[DateDefinitionFieldConfigurationTimeFormat] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
