# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .file import File


class FileRemoteUploadResponse(UncheckedBaseModel):
    data: File
    links: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Link to asset operation status
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
