# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.webhook_events import WebhookEvents


class WebhookCreateParamsData(UncheckedBaseModel):
    events: WebhookEvents
    name: str
    url: str = pydantic.Field()
    """
    URL where `event` is sent
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
