# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .user_single_definition_field_configuration import UserSingleDefinitionFieldConfiguration
from .user_single_definition_field_type import UserSingleDefinitionFieldType


class UserSingleDefinition(UncheckedBaseModel):
    created_at: dt.datetime = pydantic.Field()
    """
    Created Timestamp
    """

    creator_id: str = pydantic.Field()
    """
    Field definition creator ID
    """

    field_configuration: UserSingleDefinitionFieldConfiguration
    field_type: UserSingleDefinitionFieldType = pydantic.Field()
    """
    Field type
    """

    id: str = pydantic.Field()
    """
    Field definition ID
    """

    mutable: bool = pydantic.Field()
    """
    Field definition mutability. System fields cannot be updated.
    """

    name: str = pydantic.Field()
    """
    FieldDefinition Name
    """

    updated_at: dt.datetime = pydantic.Field()
    """
    Updated Timestamp
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
