# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .project_update_params_data_status import ProjectUpdateParamsDataStatus


class ProjectUpdateParamsData(UncheckedBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project Name
    """

    restricted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the project is restricted or not
    """

    status: typing.Optional[ProjectUpdateParamsDataStatus] = pydantic.Field(default=None)
    """
    Project Status
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
