# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .update_share_params_data_access import UpdateShareParamsDataAccess


class UpdateShareParamsData(UncheckedBaseModel):
    access: typing.Optional[UpdateShareParamsDataAccess] = None
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Share description - NOTE: Requires feature custom_branded_shares
    """

    downloading_enabled: typing.Optional[bool] = None
    expiration: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Expiration timestamp
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Share Name (must include at least one non-whitespace character and no line breaks)
    """

    passphrase: typing.Optional[str] = pydantic.Field(default=None)
    """
    Passphrase to access share, if passphrase is required and not given it will be generated
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
