# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .audit_logwith_includes_event_type import AuditLogwithIncludesEventType
from .audit_logwith_includes_resource_type import AuditLogwithIncludesResourceType
from .user import User


class AuditLogwithIncludes(UncheckedBaseModel):
    """
    Frame.io Audit Event
    """

    account_id: str
    event_type: AuditLogwithIncludesEventType
    inserted_at: str
    ip_address: str
    project_id: typing.Optional[str] = None
    resource_id: str
    resource_type: AuditLogwithIncludesResourceType
    user: typing.Optional[User] = None
    user_id: str
    workspace_id: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
