# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_user_roles_response_data_role import UpdateUserRolesResponseDataRole


class UpdateUserRolesResponseData(UncheckedBaseModel):
    role: typing.Optional[UpdateUserRolesResponseDataRole] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
