# This file was auto-generated by Fern from our API Definition.

import typing

FileSort = typing.Union[
    typing.Literal[
        "name_asc",
        "created_at_asc",
        "updated_at_asc",
        "file_size_asc",
        "name_desc",
        "created_at_desc",
        "updated_at_desc",
        "file_size_desc",
    ],
    typing.Any,
]
