# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_user_single_definition_params_field_configuration_custom_members_item import (
    UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem,
)
from .update_user_single_definition_params_field_configuration_member_options_type import (
    UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType,
)


class UpdateUserSingleDefinitionParamsFieldConfiguration(UncheckedBaseModel):
    custom_members: typing.Optional[
        typing.List[UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem]
    ] = None
    member_options_type: UpdateUserSingleDefinitionParamsFieldConfigurationMemberOptionsType
    notify_members: bool = pydantic.Field()
    """
    
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
