# This file was auto-generated by Fern from our API Definition.

import typing

UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType = typing.Union[
    typing.Literal["user", "account_user_group"], typing.Any
]
