# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .file import File
from .upload_url import UploadUrl


class FileWithUploadUrls(File):
    upload_urls: typing.Optional[typing.List[UploadUrl]] = pydantic.Field(default=None)
    """
    File upload URLs. Number of URLs returned will vary depending on the file size.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
