# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class FileCreateParamsData(UncheckedBaseModel):
    file_size: int = pydantic.Field()
    """
    File size in bytes (up to 5TB)
    """

    media_type: str = pydantic.Field()
    """
    MIME type, 
    Example: image/gif
    """

    name: str = pydantic.Field()
    """
    File name
    """

    source_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Source URL - Initiates a remote upload from the given URL when present
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
