# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .user import User
from .user_role_role import UserRoleRole


class UserRole(UncheckedBaseModel):
    """
    Frame.io User Role
    """

    role: UserRoleRole
    user: User

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
