# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.uuid_ import Uuid
from .bulk_update_metadata_params_data_values_item import BulkUpdateMetadataParamsDataValuesItem


class BulkUpdateMetadataParamsData(UncheckedBaseModel):
    file_ids: typing.List[Uuid] = pydantic.Field()
    """
    Files for bulk updates
    """

    values: typing.List[BulkUpdateMetadataParamsDataValuesItem] = pydantic.Field()
    """
    Metadata field and value mapping params. 
    Note: Select and MultiSelect field values should be passed as lists, eg: [<uuid>]. Users and MultiUser values should be passed as lists formatted as follows: [{id: <user_id>, type: "user"}, {id: <user_group_id>, type: "account_user_group"}
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
