# This file was auto-generated by Fern from our API Definition.

import typing

AuditLogwithIncludesResourceType = typing.Union[
    typing.Literal[
        "account",
        "account_field_definition",
        "account_member",
        "account_user_group",
        "action",
        "allowed_domain",
        "anonymous_user",
        "asset",
        "asset_metadata",
        "collaborator",
        "collection",
        "comment",
        "comment_impression",
        "folder",
        "join_request",
        "login_factor",
        "media",
        "oauth_app",
        "pending_account_member",
        "pending_collaborator",
        "pending_reviewer",
        "pending_team_member",
        "plan",
        "presentation",
        "project",
        "project_field_definition",
        "project_invite_link",
        "project_preference",
        "reset_token",
        "review_link",
        "reviewer",
        "sbwm_template",
        "share",
        "subscription",
        "subscription_line_item",
        "team",
        "team_member",
        "transfer_batch",
        "user",
        "user_token",
        "v4_planned_migration",
        "version_stack",
        "webhook",
    ],
    typing.Any,
]
