# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .add_reviewers_to_share_params_data_reviewers import AddReviewersToShareParamsDataReviewers


class AddReviewersToShareParamsData(UncheckedBaseModel):
    message: str = pydantic.Field()
    """
    Message for notification content
    """

    reviewers: AddReviewersToShareParamsDataReviewers

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
