# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .metadata_field import MetadataField


class MetadataWithDefinition(UncheckedBaseModel):
    file_id: str = pydantic.Field()
    """
    File ID
    """

    metadata: typing.List[MetadataField] = pydantic.Field()
    """
    Metadata fields values
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
