# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .webhook import Webhook


class WebhookCreateResponseData(Webhook):
    secret: str = pydantic.Field()
    """
    Secret used to validate webhook requests. Make sure to store your secret. You won’t be able to see it again!
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
